from celery import shared_task
from pythonthaibulksms.django import django_thaibulksms_sms


@shared_task
def django_thaibulksms_sms_celery(
        msisdn,
        message,
        config='default',
        schedule=None
    ):
        django_thaibulksms_sms(
            msisdn,
            message,
            config=config,
            schedule=schedule
        )


import requests
import xml.etree.ElementTree as ET
from urllib.parse import urlencode


"""
Example usage:

from pythonthaibulksms.thaibulksms import thaibulksms_sms

thaibulksms_sms(
    'YOUR_USERNAME',
    'YOUR_PASSWORD',
    '0899999999', # recipient phone number
    'Hello! How are you?', # message
    True,  # True = corporate, False = standard
    sender='MY COMPANY', # optional, needs to be set up in advance with thaibulksms.com
    schedule='2009301116', # optional, format YYMMDDhhmm
)
"""
def thaibulksms_sms(username, password, msisdn, message, corporate, sender=None, schedule=None):
    # required parameters
    data = {
        'username': username,
        'password': password,
        'msisdn': msisdn,
        'message': message,
        'force': 'premium' if corporate else 'standard'
    }
    #
    # optional parameters
    if schedule:
        data['ScheduledDelivery'] = schedule
    if sender:
        data['sender'] = sender
    #
    # call api
    return thaibulksms_api('https://www.thaibulksms.com/sms_api.php', data)

# todo: add thaibulksms_requestotp

# todo: add thaibulksms_verifyotp

def thaibulksms_api(url, data, format_response=True):
    r = requests.post(
        url,
        data=urlencode(data),
        headers={
            'accept': 'application/xml',
            'content-type': 'application/x-www-form-urlencoded'
        }
    )

    # extract data from response
    if format_response:
        root = ET.ElementTree(ET.fromstring(r.text)).getroot()
        response = []

        # sms api
        if root.tag.lower() == 'sms':
            for queue in root:
                contents = {}
                for el in queue.iter():
                    tag = el.tag.lower()
                    if tag in ['detail', 'msisdn', 'transaction']:
                        contents[tag] = el.text
                    elif tag in ['status', 'usedcredit', 'remaincredit']:
                        contents[tag] = int(el.text)
                response.append(contents)

        # otp api (todo)
        #
        #

    if not format_response:
        response = r.text

    # return
    return {
        'status': r.status_code,
        'response': response
    }


from django.conf import settings
from pythonthaibulksms.thaibulksms import thaibulksms_sms


"""
In your settings.py

THAIBULKSMS = {
    'default': {
        'username': 'YOUR_USERNAME',
        'password': 'YOUR_PASSWORD',
        'corporate': True,
        'sender': 'MY COMPANY' # optional, needs to be set up in advance with thaibulksms.com
    },
    'other_company': {
        'username': 'YOUR_OTHER_USERNAME',
        'password': 'YOUR_OTHER_PASSWORD',
        'corporate': True,
        'sender': 'MY OTHER COMPANY' # optional, needs to be set up in advance with thaibulksms.com
    }
}

Example usage:

from pythonthaibulksms.django import django_thaibulksms_sms

django_thaibulksms_sms(
    '0899999999', # recipient phone number
    'Hello! How are you?', # message
    'other_company', # optional, which config to use from your settings.py
    schedule='2009301116', # optional, format YYMMDDhhmm
)
"""

def django_thaibulksms_sms(msisdn, message, config='default', schedule=None):
    return thaibulksms_sms(
        settings.THAIBULKSMS[config]['username'],
        settings.THAIBULKSMS[config]['password'],
        msisdn,
        message,
        settings.THAIBULKSMS[config].get('corporate', False),
        sender=settings.THAIBULKSMS[config].get('sender', None),
        schedule=schedule
    )


# -*- coding: utf-8 -*-
from distutils.core import setup

setup(
    name='python-thaibulksms',
    version='0.0.2',
    author=u'Jon Combe',
    author_email='jon@salebox.io',
    packages=['pythonthaibulksms'],
    include_package_data=True,
    install_requires=[],
    url='https://github.com/joncombe/python-thaibulksms',
    license='BSD licence, see LICENCE file',
    description='Python functions to send SMSs via ThaiBulkSMS.com',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    zip_safe=False,
)
